package com.ruoyi.ss.channel.service.impl;

import com.ruoyi.common.auth.ali.AliConfig;
import com.ruoyi.common.pay.tm.config.TmPayConfig;
import com.ruoyi.common.pay.wx.config.WxPayConfig;
import com.ruoyi.common.pay.xy.config.XyPayConfig;
import com.ruoyi.ss.channel.domain.ChannelConfig;
import com.ruoyi.ss.channel.domain.ChannelVO;
import com.ruoyi.ss.channel.domain.enums.ChannelApiType;
import com.ruoyi.ss.channel.service.ChannelConverter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @author wjh
 * 2025/1/7
 */
@Service
public class ChannelConverterImpl implements ChannelConverter {

    @Autowired
    private WxPayConfig defaultWxPayConfig;

    @Autowired
    private AliConfig defaultAliConfig;

    @Autowired
    private TmPayConfig defaultTmConfig;

    @Override
    public Object toConfig(ChannelVO channel) {
        if (channel == null || channel.getChannelConfig() == null) {
            return null;
        }

        ChannelConfig channelConfig = channel.getChannelConfig();

        // 微信
        if (ChannelApiType.WECHAT.getType().equals(channel.getApiType())) {
            WxPayConfig config = new WxPayConfig();
            config.setAppId(channelConfig.getAppId());
            config.setMerchantId(channelConfig.getMerchantId());
            config.setApiV3Key(channelConfig.getApiV3Key());
            config.setNotifyUrl(defaultWxPayConfig.getNotifyUrl());
            config.setRefundNotifyUrl(defaultWxPayConfig.getRefundNotifyUrl());
            config.setPrivateKeyPath(channelConfig.getPrivateKeyPath());
            config.setMerchantSerialNumber(channelConfig.getMerchantSerialNumber());
            return config;
        }
        // 支付宝
        else if (ChannelApiType.ALI.getType().equals(channel.getApiType())) {
            AliConfig config = new AliConfig();
            config.setAppId(channelConfig.getAppId());
            config.setPrivateKey(channelConfig.getPrivateKey());
            config.setAesPrivateKey(channelConfig.getAesPrivateKey());
            config.setNotifyUrl(defaultAliConfig.getNotifyUrl() + "/" +  channel.getChannelId());
            config.setTransferNotifyUrl(defaultAliConfig.getTransferNotifyUrl() + "/" + channel.getChannelId());
            config.setAppCertPath(channelConfig.getAppCertPath());
            config.setAlipayCertPath(channelConfig.getAlipayCertPath());
            config.setAlipayRootCertPath(channelConfig.getAlipayRootCertPath());
            return config;
        }
        // 太米
        else if (ChannelApiType.TM_WX.getType().equals(channel.getApiType())) {
            TmPayConfig config = new TmPayConfig();
            config.setDeveloperId(channelConfig.getDeveloperId());
            config.setShopId(channelConfig.getShopId());
            config.setSignKey(channelConfig.getSignKey());
            config.setHttpUrl(defaultTmConfig.getHttpUrl());
            config.setSn(defaultTmConfig.getSn());
            config.setNotifyUrl(defaultTmConfig.getNotifyUrl() + "/" + channel.getChannelId());
            return config;
        }
        // 国通星驿
        else if (ChannelApiType.XY_WX.getType().equals(channel.getApiType())) {
            XyPayConfig config = new XyPayConfig();
            config.setAppId(channelConfig.getAppId());
            config.setPublicKey(channelConfig.getPublicKey());
            config.setAgetId(channelConfig.getAgetId());
            config.setCustId(channelConfig.getCustId());
            config.setHost(channelConfig.getHost());
            return config;
        }

        return null;
    }
}
